#Script d'initialisation de la base MySQL pour ECaMM

# Migration de v1.0 vers v1.1
# alter table ARCHIVE add A_NUMDO INT UNSIGNED;
# alter table ARCHIVE add index A_NUMDO_IDX (A_NUMDO);

#create database ecamm;
#use ecamm

create table USER
(
    U_ID       INT UNSIGNED      not null auto_increment,
    U_LOGIN    VARCHAR(30)       not null,
    U_PASSWD   VARCHAR(30)       not null,
    primary key (U_ID)
) TYPE=MYISAM;

create table CATEGORIE
(
    CA_ID      INT UNSIGNED      not null auto_increment,
    CA_NOM     VARCHAR(50)       not null,
    primary key (CA_ID)
) TYPE=MYISAM;

create table CIRCO
(
    CI_ID      INT UNSIGNED      not null auto_increment,
    CI_NOM     VARCHAR(50)       not null,
    primary key (CI_ID)
) TYPE=MYISAM;

create table DEMANDE
(
    D_ID       INT UNSIGNED      not null auto_increment,
    D_U_IDO    INT UNSIGNED      not null,
    D_CA_ID    INT UNSIGNED      not null default '1',
    D_PROB     LONGTEXT                  ,
    D_SOL      LONGTEXT                  ,
    D_TYPE     TINYINT           not null,
    D_PRI      TINYINT                   ,
    D_DATEO    DATETIME                  ,
    D_FLAG     INT UNSIGNED      not null default '0',
    D_ETAT     TINYINT           not null default '1',
    primary key (D_ID),
    foreign key  (D_U_IDO) references USER (U_ID),
    index D_U_FK (D_U_IDO),
    foreign key  (D_CA_ID) references CATEGORIE (CA_ID),
    index D_CA_FK (D_CA_ID)
) TYPE=MYISAM;

create table ARCHIVE
(
    A_ID       INT UNSIGNED      not null auto_increment,
    A_U_IDO    INT UNSIGNED      not null,
    A_U_IDC    INT UNSIGNED      not null,
    A_CA_ID    INT UNSIGNED      not null,
    A_PROB     LONGTEXT                  ,
    A_SOL      LONGTEXT                  ,
    A_TYPE     TINYINT           not null,
    A_DATEC    DATETIME                  ,
    A_DATEO    DATETIME                  ,
    A_NUMDO    INT UNSIGNED     	 ,
    primary key (A_ID),
    foreign key  (A_U_IDO) references USER (U_ID),
    index A_UO_FK (A_U_IDO),
    foreign key  (A_U_IDC) references USER (U_ID),
    index A_UC_FK (A_U_IDC),
    foreign key  (A_CA_ID) references CATEGORIE (CA_ID),
    index A_CA_FK (A_CA_ID),
    FULLTEXT (A_SOL,A_PROB),
    index A_NUMDO_IDX (A_NUMDO) 
) TYPE=MYISAM;

create table COMMUNE
(
    CO_ID      INT UNSIGNED      not null auto_increment,
    CO_CI_ID   INT UNSIGNED      not null,
    CO_NOM     VARCHAR(50)       not null,
    CO_POSTAL  VARCHAR(20)               ,
    primary key (CO_ID),
    foreign key  (CO_CI_ID) references CIRCO (CI_ID),
    index CO_CI_FK (CO_CI_ID)
) TYPE=MYISAM;

create table CONTACT
(
    CT_ID      INT UNSIGNED      not null auto_increment,
    CT_CI_ID   INT UNSIGNED      not null,
    CT_NOM     VARCHAR(50)       not null,
    CT_PRENOM  VARCHAR(50)               ,
    CT_MAIL    VARCHAR(50)               ,
    CT_TELW    VARCHAR(20)               ,
    CT_TELP    VARCHAR(20)               ,
    CT_ORGA    VARCHAR(50)               ,
    primary key (CT_ID),
    foreign key  (CT_CI_ID) references CIRCO (CI_ID),
    index CT_CI_FK (CT_CI_ID)
) TYPE=MYISAM;

create table ETABLISSEMENT
(
    ET_ID      INT UNSIGNED      not null auto_increment,
    ET_CO_ID   INT UNSIGNED      not null,
    ET_NOM     VARCHAR(50)       not null,
    ET_RNE     VARCHAR(20)               ,
    ET_SLIS    VARCHAR(50)               ,
    primary key (ET_ID),
    foreign key  (ET_CO_ID) references COMMUNE (CO_ID),
    index ET_CO_FK (ET_CO_ID)
) TYPE=MYISAM;

create table ETD
(
    ETD_ET_ID  INT UNSIGNED      not null,
    ETD_D_ID   INT UNSIGNED      not null,
    primary key (ETD_ET_ID, ETD_D_ID),
    foreign key  (ETD_ET_ID) references ETABLISSEMENT (ET_ID),
    index ETD_ET_FK (ETD_ET_ID),
    foreign key  (ETD_D_ID) references DEMANDE (D_ID),
    index ETD_D_FK (ETD_D_ID)
) TYPE=MYISAM;

create table ETA
(
    ETA_A_ID   INT UNSIGNED      not null,
    ETA_ET_ID  INT UNSIGNED      not null,
    primary key (ETA_A_ID, ETA_ET_ID),
    foreign key  (ETA_A_ID) references ARCHIVE (A_ID),
    index ETA_A_FK (ETA_A_ID),
    foreign key  (ETA_ET_ID) references ETABLISSEMENT (ET_ID),
    index ETA_ET_FK (ETA_ET_ID)
) TYPE=MYISAM;

create table CTD
(
    CTD_D_ID   INT UNSIGNED      not null,
    CTD_CT_ID  INT UNSIGNED      not null,
    primary key (CTD_D_ID, CTD_CT_ID),
    foreign key  (CTD_D_ID) references DEMANDE (D_ID),
    index CTD_D_FK (CTD_D_ID),
    foreign key  (CTD_CT_ID) references CONTACT (CT_ID),
    index CTD_CT_FK (CTD_CT_ID)
) TYPE=MYISAM;

create table CTA
(
    CTA_CT_ID  INT UNSIGNED      not null,
    CTA_A_ID   INT UNSIGNED      not null,
    primary key (CTA_CT_ID, CTA_A_ID),
    foreign key  (CTA_CT_ID) references CONTACT (CT_ID),
    index CTA_CT_FK (CTA_CT_ID),
    foreign key  (CTA_A_ID) references ARCHIVE (A_ID),
    index CTA_A_FK (CTA_A_ID)
) TYPE=MYISAM;

insert into CATEGORIE (CA_ID,CA_NOM) values (1,'Aucune');
insert into CIRCO (CI_ID,CI_NOM) values (1,'Aucune');
